@@ -1,4 +1,4 @@
-## Copyright (C) 2022 Rodney A. Sparapani
+## Copyright (C) 2022-2025 Rodney A. Sparapani
 
 ## This file is part of nftbart.
 ## nft2.R
@@ -23,7 +23,7 @@ nft2 = function(## data
                xftrain, xstrain, times, delta=NULL, 
                xftest=matrix(nrow=0, ncol=0),
                xstest=matrix(nrow=0, ncol=0),
-               rm.const=TRUE, rm.dupe=TRUE,
+               rm.const=TRUE, rm.dupe=TRUE, right.max=Inf,
                ##edraws2=matrix(nrow=0, ncol=0),
                ##zdraws2=matrix(nrow=0, ncol=0),
                ##impute.bin=NULL, impute.prob=NULL,
@@ -77,49 +77,96 @@ nft2 = function(## data
         if(np!=nrow(xstest))
             stop('The number of rows in xftest and xstest must be the same')
 
+        ## preliminary: could change based on bMM 
+        pf=ncol(xftrain)
+        ps=ncol(xstrain)
+
         if(np>0) {
-            xf.=bMM(rbind(xftrain, xftest), numcut=numcut, rm.const=rm.const, rm.dupe=rm.dupe,
-                   method=method, use=use)
-            xftrain=cbind(xf.$X[1:n, ])
-            xftest =cbind(xf.$X[n+(1:np), ])
-            xs.=bMM(rbind(xstrain, xstest), numcut=numcut, rm.const=rm.const, rm.dupe=rm.dupe,
-                   method=method, use=use)
-            xstrain=cbind(xs.$X[1:n, ])
-            xstest =cbind(xs.$X[n+(1:np), ])
+            xftrain. <- rbind(xftrain, xftest)
+            xstrain. <- rbind(xstrain, xstest)
+            ## if(length(xifcuts)==0) xifcuts=xicuts(xftrain., numcut=numcut)
+            ## if(length(xiscuts)==0) xiscuts=xicuts(xstrain., numcut=numcut)
+            impute=CDimpute(x.train=xftrain, x.test=xftest)
+            xftrain=impute$x.train
+            xftest=impute$x.test
+            xf.=bMM(rbind(xftrain, xftest), numcut=numcut, rm.const=rm.const,
+                   rm.dupe=rm.dupe, method=method, use=use, xicuts = xifcuts)
+            xftrain=t(cbind(xf.$X[1:n, ]))
+            xftest =t(cbind(xf.$X[n+(1:np), ]))
+            if(length(xifcuts)==0) xifcuts=xf.$xicuts
+            chvf = xf.$chv
+            if(pf == ps && !is.na(all(xftrain.[!is.na(xftrain.)] == xstrain.[!is.na(xftrain.)])) && all(xftrain.[!is.na(xftrain.)] == xstrain.[!is.na(xftrain.)])) {
+                xstrain <- xftrain
+                xstest  <- xftest
+                chvs <- chvf
+                xiscuts <- xifcuts
+            } else {
+                impute=CDimpute(x.train=xstrain, x.test=xstest)
+                xstrain=impute$x.train
+                xstest=impute$x.test
+                xs.=bMM(rbind(xstrain, xstest), numcut=numcut, rm.const=rm.const, 
+                    rm.dupe=rm.dupe, method=method, use=use, xicuts = xiscuts)
+                xstrain=t(cbind(xs.$X[1:n, ]))
+                xstest =t(cbind(xs.$X[n+(1:np), ]))
+                chvs = xs.$chv
+                if(length(xiscuts)==0) xiscuts=xs.$xicuts
+            }
         } else {
-            xf.=bMM(xftrain, numcut=numcut, rm.const=rm.const, rm.dupe=rm.dupe,
-                   method=method, use=use)
-            xftrain=xf.$X
-            xs.=bMM(xstrain, numcut=numcut, rm.const=rm.const, rm.dupe=rm.dupe,
-                   method=method, use=use)
-            xstrain=xs.$X
+            ## if(length(xifcuts)==0) xifcuts=xicuts(xftrain, numcut=numcut)
+            ## if(length(xiscuts)==0) xiscuts=xicuts(xstrain, numcut=numcut)
+            impute=CDimpute(x.train=xftrain)
+            xftrain. <- xftrain
+            xftrain=impute$x.train
+            xf.=bMM(xftrain, numcut=numcut, rm.const=rm.const, 
+                    rm.dupe=rm.dupe, method=method, use=use, xicuts = xifcuts)
+            xftrain=t(xf.$X)
+            chvf = xf.$chv
+            if(length(xifcuts)==0) xifcuts=xf.$xicuts
+            if(pf == ps && !is.na(all(xftrain.[!is.na(xftrain.)] == xstrain[!is.na(xftrain.)])) && all(xftrain.[!is.na(xftrain.)] == xstrain[!is.na(xftrain.)])) {
+                xstrain <- xftrain
+                chvs <- chvf
+                xiscuts <- xifcuts
+            } else {
+                impute=CDimpute(x.train=xstrain)
+                xstrain=impute$x.train
+                xs.=bMM(xstrain, numcut=numcut, rm.const=rm.const, 
+                    rm.dupe=rm.dupe, method=method, use=use, xicuts = xiscuts)
+                xstrain=t(xs.$X)
+                chvs = xs.$chv
+                if(length(xiscuts)==0) xiscuts=xs.$xicuts
+            }
         }
-        xifcuts=xf.$xicuts
-        xiscuts=xs.$xicuts
-        chvf = xf.$chv
-        chvs = xs.$chv
+        ##if(length(xifcuts)==0) xifcuts=xf.$xicuts
+        ##if(length(xiscuts)==0) xiscuts=xs.$xicuts
+        ##chvf = xf.$chv
+        ##chvs = xs.$chv
         
-        impute=CDimpute(x.train=xftrain, x.test=xftest)
-        xftrain=t(impute$x.train)
-        xftest=t(impute$x.test)
-        impute=CDimpute(x.train=xstrain, x.test=xstest)
-        xstrain=t(impute$x.train)
-        xstest=t(impute$x.test)
+        ## impute=CDimpute(x.train=xftrain, x.test=xftest)
+        ## xftrain=t(impute$x.train)
+        ## xftest=t(impute$x.test)
+        ## impute=CDimpute(x.train=xstrain, x.test=xstest)
+        ## xstrain=t(impute$x.train)
+        ## xstest=t(impute$x.test)
         transposed=TRUE
     } else {
         np=ncol(xftest)
         if(length(chvf)==0) chvf = cor(t(xftrain), method=method, use=use)
         if(length(chvs)==0) chvs = cor(t(xstrain), method=method, use=use)
 
-        if(length(xifcuts)==0) 
-            xifcuts=xicuts(xftrain, transposed=transposed, numcut=numcut)
-        if(length(xiscuts)==0) 
-            xiscuts=xicuts(xstrain, transposed=transposed, numcut=numcut)
+        if(length(xifcuts)==0) xifcuts=xicuts(xftrain, TRUE, numcut)
+        if(length(xiscuts)==0) xiscuts=xicuts(xstrain, TRUE, numcut)
     }
     
     pf=nrow(xftrain)
     ps=nrow(xstrain)
 
+    if(np>0) {
+        if(pf!=nrow(xftest))
+          stop('The number of columns in xftrain and xftest must be the same')
+        if(ps!=nrow(xstest))
+          stop('The number of columns in xstrain and xstest must be the same')
+    }
+
     take.logs = (dist!='extreme')
     if(length(events)==0 && K>0) {
         events <- unique(quantile(times, probs=(0:(K-1))/(K-1)))
@@ -161,6 +208,7 @@ nft2 = function(## data
     if(take.logs) {
         y=log(times)-fmu
         if(K>0) events=log(events)
+        right.max <- log(right.max)-fmu
     } else {
         y=times-fmu
     }
@@ -213,7 +261,7 @@ nft2 = function(## data
     res=.Call("cnft2",
               xftrain, xstrain,
               y,
-              as.integer(delta),
+              as.integer(delta), right.max,
               xftest, xstest,
               c(ntree[1], ntree[2]),
               nd,
@@ -342,7 +390,8 @@ if(K>0) {
     res$xiscuts=xiscuts
     ##res$fmu = fmu
     res$NFT=list(total.lambda = total.lambda, total.nu = total.nu,
-                 fmu=fmu, tau=tau, k=k) ## , sigmaf=sigmaf)
+                 fmu=fmu, tau=tau, k=k, right.max = right.max+fmu)
+    ## , sigmaf=sigmaf)
 
     if(drawDPM>0) {
         ## res$prior = prior
