@@ -13,7 +13,7 @@ extern SEXP cpsambrt_predict2(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SE
 //extern SEXP cprnft(SEXP, SEXP, SEXP, SEXP);
 extern SEXP cprnft2(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 //extern SEXP cnft(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP cnft2(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP cnft2(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
 //    {"cpsambrt_predict", (DL_FUNC) &cpsambrt_predict,  7},
@@ -21,7 +21,7 @@ static const R_CallMethodDef CallEntries[] = {
 //    {"cprnft",           (DL_FUNC) &cprnft,            4},
     {"cprnft2",          (DL_FUNC) &cprnft2,           6},
 //    {"cnft",             (DL_FUNC) &cnft,             32},
-    {"cnft2",            (DL_FUNC) &cnft2,            33},
+    {"cnft2",            (DL_FUNC) &cnft2,            34},
     {NULL, NULL, 0}
 };
 
